'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var VALUE_RENDERERS = {
  String: function String(raw) {
    return '"' + raw + '"';
  },
  Boolean: function Boolean(raw) {
    return raw ? 'true' : 'false';
  },
  Date: function Date(raw) {
    return raw.toISOString();
  },
  Null: function Null() {
    return 'null';
  },
  Undefined: function Undefined() {
    return 'undefined';
  },
  Function: function Function(raw) {
    return raw.toString();
  },
  Symbol: function Symbol(raw) {
    return raw.toString();
  }
};

/**
 * Renders simple values (eg. strings, numbers, booleans, etc)
 */

var JSONValueNode = function JSONValueNode(_ref) {
  var nodeType = _ref.nodeType,
      styling = _ref.styling,
      renderLabel = _ref.renderLabel,
      keyPath = _ref.keyPath,
      renderValue = _ref.renderValue,
      value = _ref.value;

  var renderedValue = VALUE_RENDERERS.hasOwnProperty(nodeType) ? VALUE_RENDERERS[nodeType](value) : value;

  return _react2.default.createElement(
    'li',
    styling(['value', 'valueColor'], nodeType, keyPath),
    _react2.default.createElement(
      'label',
      styling(['label', 'labelColor', 'valueLabel', 'valueLabelColor'], nodeType, keyPath),
      renderLabel(keyPath, nodeType, false, false)
    ),
    _react2.default.createElement(
      'span',
      styling(['valueText', 'valueTextColor'], nodeType, keyPath),
      renderValue.apply(undefined, [renderedValue, value].concat((0, _toConsumableArray3.default)(keyPath)))
    )
  );
};

exports.default = JSONValueNode;